@@ -25,8 +25,7 @@ use crate::extensions::ExtensionEnvironment;
 use crate::task::Runner;
 use anyhow::{anyhow, Result};
 use clap::{App, Arg};
-use std::collections::BTreeMap;
-use std::collections::HashSet;
+use std::collections::{BTreeMap, HashMap, HashSet};
 use std::fs;
 extern crate num_cpus;
 use crate::engines::replace_env_vars_static;
@@ -45,7 +44,7 @@ mod server;
 
 use std::path::PathBuf;
 
-const CHOMP_CORE: &str = "https://ga.jspm.io/npm:@chompbuild/extensions@0.1.16/";
+const CHOMP_CORE: &str = "https://ga.jspm.io/npm:@chompbuild/extensions@0.1.18/";
 
 const CHOMP_INIT: &str = r#"version = 0.1
 
@@ -56,7 +55,7 @@ name = 'build'
 run = 'echo \"Build script goes here\"'
 "#;
 
-const CHOMP_INIT_SCRIPTS: &str = "version = 0.1\n";
+const CHOMP_EMPTY: &str = "version = 0.1\n";
 
 fn uri_parse(uri_str: &str) -> Option<Uri> {
     match uri_str.parse::<Uri>() {
@@ -71,9 +70,9 @@ fn uri_parse(uri_str: &str) -> Option<Uri> {
 #[tokio::main]
 async fn main() -> Result<()> {
     #[cfg(not(debug_assertions))]
-    let version = "0.1.11";
+    let version = "0.1.13";
     #[cfg(debug_assertions)]
-    let version = "0.1.11-debug";
+    let version = "0.1.13-debug";
     let matches = App::new("Chomp")
         .version(version)
         .arg(
@@ -210,15 +209,19 @@ async fn main() -> Result<()> {
             if matches.is_present("init") {
                 created = true;
                 if matches.is_present("import_scripts") {
-                    String::from(CHOMP_INIT_SCRIPTS)
+                    String::from(CHOMP_EMPTY)
                 } else {
                     String::from(CHOMP_INIT)
                 }
             } else {
-                return Err(anyhow!(
-                    "Unable to load the Chomp configuration {}. Pass the \x1b[1m--init\x1b[0m flag to create one, or try:\n\n\x1b[36mchomp --init --import-scripts\x1b[0m\n\nto create one and import from existing package.json scripts.",
-                    &cfg_file.to_str().unwrap()
-                ));
+                if matches.is_present("serve") {
+                    String::from(CHOMP_EMPTY)
+                } else {
+                    return Err(anyhow!(
+                        "Unable to load the Chomp configuration {}. Pass the \x1b[1m--init\x1b[0m flag to create one, or try:\n\n\x1b[36mchomp --init --import-scripts\x1b[0m\n\nto create one and import from existing package.json scripts.",
+                        &cfg_file.to_str().unwrap()
+                    ));
+                }
             }
         }
     };
@@ -406,6 +409,7 @@ async fn main() -> Result<()> {
         || matches.is_present("eject_templates")
         || matches.is_present("list")
         || matches.is_present("import_scripts")
+        || matches.is_present("init")
     {
         use_default_target = false;
         if matches.is_present("eject_templates") {
@@ -416,6 +420,7 @@ async fn main() -> Result<()> {
                 ));
             }
             chompfile.extensions = Vec::new();
+            chompfile.template_options = HashMap::new();
         }
 
         if matches.is_present("list") {
