@@ -742,11 +742,13 @@ impl<'a> Runner<'a> {
         };
         if job.parents.len() > 0 {
             for parent in job.parents.clone() {
+                if parent == job_num {
+                    continue;
+                }
                 self.invalidate_job(parent, queued, redrives)?;
             }
-        } else {
-            redrives.insert(job_num);
         }
+        redrives.insert(job_num);
         Ok(())
     }
 
@@ -864,8 +866,8 @@ impl<'a> Runner<'a> {
                                             .invalidation
                                             .unwrap_or_default()
                                         {
-                                            InvalidationCheck::NotFound => false,
-                                            InvalidationCheck::Always
+                                            InvalidationCheck::NotFound
+                                            | InvalidationCheck::Always
                                             | InvalidationCheck::Mtime => match dep.mtime {
                                                 Some(dep_mtime) => dep_mtime > mtime,
                                                 None => true,
